==> galeon-0.10.2.tar.gz: galeon-0.10.2/src/mozilla_i18n.c <==
#include "galeon.h"

char *lgroups[NUM_TRANSLATED_CHARSET_GROUPS] = {
	N_("Arabic"),
	N_("Baltic"),
	N_("Central European"),
	N_("Chinese"),
	N_("Cyrillic"),
	N_("Greek"),
	N_("Hebrew"),
	N_("Japanese"), 
	N_("Turkish"),
	N_("Unicode"),
	N_("UTF"),
	N_("Vietnamese"),
	N_("Western")
};

char *charset_trans_array[NUM_TRANSLATED_CHARSETS] = { 
	N_("Arabic (IBM-864)"),
	N_("Arabic (ISO-8859-6)"),
	N_("Arabic (ISO-8859-6-E)"),
	N_("Arabic (ISO-8859-6-I)"),
	N_("Arabic (Windows-1256)"),
	N_("Armenian (ARMSCII-8)"),
	N_("Baltic (ISO-8859-13)"),
	N_("Baltic (ISO-8859-4)"),
	N_("Baltic (Windows-1257)"),
	N_("Celtic (ISO-8859-14)"),
	N_("Central European (IBM-852)"),
	N_("Central European (ISO-8859-2)"),
	N_("Central European (MacCE)"),
	N_("Central European (Windows-1250)"),
	N_("Chinese Simplified (GB2312)"),
	N_("Chinese Simplified (GBK)"),
	N_("Chinese Simplified (HZ)"),
	N_("Chinese Traditional (Big5)"),
	N_("Chinese Traditional (EUC-TW)"),
	N_("Croatian (MacCroatian)"),
	N_("Cyrillic (IBM-855)"),
	N_("Cyrillic (ISO-8859-5)"),
	N_("Cyrillic (ISO-IR-111)"),
	N_("Cyrillic (KOI8-R)"),
	N_("Cyrillic (MacCyrillic)"),
	N_("Cyrillic (Windows-1251)"),
	N_("Cyrillic/Russian (IBM-866)"),
	N_("Cyrillic/Ukrainian (KOI8-U)"),
	N_("Cyrillic/Ukrainian (MacUkrainian)"),
	N_("English (US-ASCII)"),
	N_("Greek (ISO-8859-7)"),
	N_("Greek (MacGreek)"),
	N_("Greek (Windows-1253)"),
	N_("Hebrew (IBM-862)"),
	N_("Hebrew (ISO-8859-8-E)"),
	N_("Hebrew (ISO-8859-8-I)"),
	N_("Hebrew (Windows-1255)"),
	N_("Icelandic (MacIcelandic)"),
	N_("Japanese (EUC-JP)"),
	N_("Japanese (ISO-2022-JP)"),
	N_("Japanese (Shift_JIS)"),
	N_("Korean (EUC-KR)"),
	N_("Nordic (ISO-8859-10)"),
	N_("Romanian (MacRomanian)"),
	N_("South European (ISO-8859-3)"),
	N_("T.61-8bit"),
	N_("Thai (TIS-620)"),
	N_("Turkish (IBM-857)"),
	N_("Turkish (ISO-8859-9)"),
	N_("Turkish (MacTurkish)"),
	N_("Turkish (Windows-1254)"),
	N_("Unicode (UTF-7)"),
	N_("Unicode (UTF-8)"),
	N_("User Defined"),
	N_("UTF-16BE"),
	N_("UTF-16LE"),
	N_("UTF-32BE"),
	N_("UTF-32LE"),
	N_("Vietnamese (TCVN)"),
	N_("Vietnamese (VISCII)"),
	N_("Vietnamese (VPS)"),
	N_("Vietnamese (Windows-1258)"),
	N_("Visual Hebrew (ISO-8859-8)"),
	N_("Western (IBM-850)"),
	N_("Western (ISO-8859-1)"),
	N_("Western (ISO-8859-15)"),
	N_("Western (MacRoman)"),
	N_("Western (Windows-1252)"),
	N_("windows-936"),
	N_("x-imap4-modified-utf7"),
	N_("x-u-escaped")
};

==> galeon-0.10.5.tar.gz: galeon-0.10.5/src/mozilla_i18n.c <==
#include "galeon.h"

const char *lgroups[] = {
	N_("Arabic"),
	N_("Baltic"),
	N_("Central European"),
	N_("Chinese"),
	N_("Cyrillic"),
	N_("Greek"),
	N_("Hebrew"),
	N_("Japanese"), 
	N_("Turkish"),
	N_("Unicode"),
	N_("UTF"),
	N_("Vietnamese"),
	N_("Western")
};

const char *charset_trans_array[] = { 
	N_("Arabic (IBM-864)"),
	N_("Arabic (IBM-864-I)"),
	N_("Arabic (ISO-8859-6)"),
	N_("Arabic (ISO-8859-6-E)"),
	N_("Arabic (ISO-8859-6-I)"),
	N_("Arabic (Windows-1256)"),
	N_("Armenian (ARMSCII-8)"),
	N_("Baltic (ISO-8859-13)"),
	N_("Baltic (ISO-8859-4)"),
	N_("Baltic (Windows-1257)"),
	N_("Celtic (ISO-8859-14)"),
	N_("Central European (IBM-852)"),
	N_("Central European (ISO-8859-2)"),
	N_("Central European (MacCE)"),
	N_("Central European (Windows-1250)"),
	N_("Chinese Simplified (GB2312)"),
	N_("Chinese Simplified (GBK)"),
	N_("Chinese Simplified (HZ)"),
	N_("Chinese Traditional (Big5)"),
	N_("Chinese Traditional (Big5-HKSCS)"),
	N_("Chinese Traditional (EUC-TW)"),
	N_("Croatian (MacCroatian)"),
	N_("Cyrillic (IBM-855)"),
	N_("Cyrillic (ISO-8859-5)"),
	N_("Cyrillic (ISO-IR-111)"),
	N_("Cyrillic (MacCyrillic)"),
	N_("Cyrillic (Windows-1251)"),
	N_("Cyrillic/Russian (KOI8-R)"),
	N_("Cyrillic/Russian (IBM-866)"),
	N_("Cyrillic/Ukrainian (KOI8-U)"),
	N_("Cyrillic/Ukrainian (MacUkrainian)"),
	N_("English (US-ASCII)"),
	N_("Greek (ISO-8859-7)"),
	N_("Greek (MacGreek)"),
	N_("Greek (Windows-1253)"),
	N_("Hebrew (IBM-862)"),
	N_("Hebrew (ISO-8859-8-E)"),
	N_("Hebrew (ISO-8859-8-I)"),
	N_("Hebrew (Windows-1255)"),
	N_("Icelandic (MacIcelandic)"),
	N_("Japanese (EUC-JP)"),
	N_("Japanese (ISO-2022-JP)"),
	N_("Japanese (Shift_JIS)"),
	N_("Korean (EUC-KR)"),
	N_("Nordic (ISO-8859-10)"),
	N_("Romanian (MacRomanian)"),
	N_("South European (ISO-8859-3)"),
	N_("Thai (TIS-620)"),
	N_("Turkish (IBM-857)"),
	N_("Turkish (ISO-8859-9)"),
	N_("Turkish (MacTurkish)"),
	N_("Turkish (Windows-1254)"),
	N_("Unicode (UTF-7)"),
	N_("Unicode (UTF-8)"),
	N_("User Defined"),
	N_("Vietnamese (TCVN)"),
	N_("Vietnamese (VISCII)"),
	N_("Vietnamese (VPS)"),
	N_("Vietnamese (Windows-1258)"),
	N_("Visual Hebrew (ISO-8859-8)"),
	N_("Western (IBM-850)"),
	N_("Western (ISO-8859-1)"),
	N_("Western (ISO-8859-15)"),
	N_("Western (MacRoman)"),
	N_("Western (Windows-1252)"),
};

const gchar *lang_encode_name[LANG_ENC_NUM] =
{
	N_("Western"),
	N_("Central European"),
	N_("Japanese"),
 	N_("Traditional Chinese"),
	N_("Simplified Chinese"),
	N_("Korean"),
	N_("Cyrillic"),
	N_("Baltic"),
	N_("Greek"),
	N_("Turkish"),
	N_("Unicode"),
	N_("User Defined"),
	N_("Thai"),
	N_("Hebrew"),
	N_("Arabic")
};

const gchar *lang_encode_item[LANG_ENC_NUM] =
{
	"x-western",
	"x-central-euro",
	"ja",
	"zh-TW",
	"zh-CN",
	"ko",
	"x-cyrillic",
	"x-baltic",
	"el",
	"tr",
	"x-unicode",
	"x-user-def",
	"th",
	"he",
	"ar"
};

gint
get_lgroups_count(void)
{
	return sizeof (lgroups) / sizeof ((lgroups)[0]);
}

gint
get_translated_cscount(void)
{
	return sizeof (charset_trans_array) / sizeof ((charset_trans_array)[0]);
}
